# Graviti Python SDK

[![Pre-commit](https://github.com/Graviti-AI/graviti-python-sdk/actions/workflows/pre-commit.yaml/badge.svg)](https://github.com/Graviti-AI/graviti-python-sdk/actions/workflows/pre-commit.yaml)
[![Documentation Status](https://readthedocs.org/projects/graviti-python-sdk/badge/?version=latest)](https://graviti-python-sdk.readthedocs.io/en/latest/?badge=latest)
[![GitHub](https://img.shields.io/github/license/Graviti-AI/graviti-python-sdk)](https://github.com/Graviti-AI/graviti-python-sdk/blob/main/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/graviti)](https://pypi.org/project/graviti/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/graviti)](https://pypi.org/project/graviti/)
[![Downloads](https://pepy.tech/badge/graviti/month)](https://pepy.tech/project/graviti)

Graviti Python SDK is a python library to access Graviti Data Platform and manage your datasets.
It provides a pythonic way to access your datasets by Graviti OpenAPI.
